@@ -1,24 +1,22 @@
 /*
  * defs.h for kdrill
- *   Okay, I lied.. this file has struct definitions, as
+ *   Okay, I "lied".. this file has struct definitions, as
  *   well as the #defines
  */
 
 #ifdef BSD
-#define srand(a) srandom(a)
-#define lrand48() random()
-/* yes, memcpy is okay.. no overlapping stuff */
-#define memcpy(dest,src,sz) bcopy((src),(dest),(sz))
-#define strchr(a,b) index((a),(b)) 
-#define HAS_BZERO
+/* It's Really Important that you use either lrand48(), or random()
+ * The old rand() function is just not random enough
+ */
+# define srand(a) srandom(a)
+# define lrand48() random()
 
-#else
-#define HAS_MEMSET
 #endif /* BSD */
 
 /* for reading in kanjidic lines */
 #define MAXLINELEN 1024
 
+#define NOKANJI 0x2266
 
 /* when in random mode, if you have incorrect kanji guessed,
  * will specifically pick an incorrectly-guessed kanji
@@ -27,14 +25,11 @@
 #define REPEATFRACTION 4
 /* number of times a missed kanji will be repeated on purpose */
 #define REPEATTIMES 2
-
+#define MAXREPEAT 10
 /* how many possible answers are there? */
 /* maximum of 9, since you can only have accelerator keys 1-9 */
 #define NUMBEROFCHOICES 5
 
-/* enum for "changemode()" */
-enum { GUESSMEANING, GUESSKANJI,TOGGLEKANA};
-
 #define STATUSDISTANCE	10
 #define BUTTONSWIDTH	120	/* for options buttons */
 #define INPUTWIDTH	50
@@ -46,10 +41,26 @@ enum { GUESSMEANING, GUESSKANJI,TOGGLEKANA};
 #define FULLWIDTH 370
 #define KANJIWIDTH 50
 
+/* MAXTRANSLATIONSALLOWED reflects the size of an array of pointer-to-translation,
+ * and an array of booleans for the Usefile
+ * We malloc for every actual entry read
+ *
+ * MIN/MAX KANJIALLOWED is a special subset of that.
+ */
 #define MINKANJIALLOWED 0x2000
 #define MAXKANJIALLOWED 0x8000
+#define MAXTRANSLATIONSALLOWED 0x18000
+/* yes, really 0x18000. edict currently has more than 0xC000,
+ *  plus 0x8000 in kdict
+ */
+
+/* The following means the minimum active translations we must have available.
+ * Otherwise, we assume an error in configuration
+ */
 #define HAVE_AT_LEAST 9
 
+typedef struct translationstruct * TRANSLATION;
+
 struct translationstruct {
 
 	char *english;	/* english translation string.
@@ -59,21 +70,30 @@ struct translationstruct {
 			 * text widget, that would be silly
 			 */
 
-	int Uindex;		/* because it seems to be the future */
+	unsigned short Uindex;		/* because it seems to be the future */
 				/* "Unicode" index */
 
-	int Nindex;		/* for annoying "See Nxxxx" references */
+	short Qindex;		/* for the "four corner" lookup method */
+	int Sindex;		/* for SKIP: 4 bytes, MSB not used */
+	short Nindex;		/* for annoying "See Nxxxx" references */
 				/* Nelson dictionary */
-	int Hindex;		/* Halpern dictionary */
+	short Hindex;		/* Halpern dictionary indexes */
 
-	int frequency;		/* frequency that kanji is used */
-	int grade_level;	/* akin to  school class level */
-	int incorrect;
-	XChar2b *pronunciation;
-	XChar2b *ON_extra;
+	short frequency;		/* frequency that kanji is used */
+	char grade_level;	/* akin to  school class level */
+	short incorrect;
+
+	
+	XChar2b *pronunciation;	/* kana, actually */
+	XChar2b *kanji;		/* can be pointer to pronunciation */
+
+	TRANSLATION nextk;
 
 };
 
+
+
+
 /********************************************************************
 
 SO here's the format for the translation/dictionary file I have decided
