@@ -3,6 +3,7 @@
 #include <stdio.h>
 
 #include <Xatom.h>
+#include <Xfuncs.h>	/* handles bzero redefine stuff */
 #include <Xos.h>
 #include <Intrinsic.h>
 #include <StringDefs.h>
@@ -18,11 +19,12 @@
 #include "game.h"
 #include "grades.h"
 #include "options.h"
+#include "search.h"
 #include "widgets.h"
 
 #include "icon_xbm"
 
-Boolean useKanji[MAXKANJIALLOWED];
+Boolean useKanji[MAXTRANSLATIONSALLOWED];
 int lowfrequency=0,highfrequency=0;
 
 char *usefile=NULL;	/* global pointer that indicates if usefile is
@@ -48,13 +50,15 @@ static char *fallback[] = {
 	"KDrill.noBell:		0",
 	"KDrill*nousefile:	0",
 	"KDrill*usefile:	.kanjiusefile", 
-	DICTLOCATION,
-	"KDrill*kanjifont:	kanji24",
-	"KDrill*smallkanji:	kanji16",
+	DICTLOCATION,	/* change this value in Imakefile !!*/
+	EDICTLOCATION,	/* change this value in Imakefile !!*/
+	"KDrill*kanjifont:	-jis-*--24*jisx0208*",
+	"KDrill*smallkanji:	-jis-*--16*jisx0208*",
 	"KDrill*englishfont:	fixed",
 	"KDrill*gradelevel:	0",
 	"KDrill*guessmeaning:	0",
 	"KDrill*showkana:	0",
+	"KDrill*romajiswitch:	0",
 	"KDrill*lowfrequency:	0",
 	"KDrill*highfrequency:	0",
 #ifdef OLDLOG
@@ -72,13 +76,15 @@ static XrmOptionDescRec optionDescList[] = {
 	{"-notallT",	".notallT",XrmoptionNoArg,"1"},
 	{"-usefile",	".usefile",	XrmoptionSepArg,(caddr_t) NULL},
 	{"-nousefile",  ".nousefile",	XrmoptionNoArg, "1"},
-	{"-dictfile",	".dictfile",	XrmoptionSepArg,(caddr_t) NULL},
+	{"-kdictfile",	".kdictfile",	XrmoptionSepArg,(caddr_t) NULL},
+	{"-edictfile",	".edictfile",	XrmoptionSepArg,(caddr_t) NULL},
 	{"-englishfont",".englishfont",	XrmoptionSepArg,(caddr_t) NULL},
 	{"-kanjifont",	".kanjifont",	XrmoptionSepArg,(caddr_t) NULL},
 	{"-smallkanji",	".smallkanji",	XrmoptionSepArg,(caddr_t) NULL},
 	{"-noBell",     ".noBell",	XrmoptionNoArg, "1"},
 	{"-guessmeaning",".guessmeaning",XrmoptionNoArg,"1"},
 	{"-showkana",   ".showkana",    XrmoptionNoArg,"1"},
+	{"-romajiswitch",   ".romajiswitch",    XrmoptionNoArg,"1"},
 	{"-showinorder",   ".showinorder",    XrmoptionNoArg,"1"},
 	{"-gradelevel", ".gradelevel",  XrmoptionSepArg,(caddr_t) NULL},
 	{"-lowfrequency",	".lowfrequency",XrmoptionSepArg,(caddr_t) NULL},
@@ -106,7 +112,11 @@ handle_delete(Widget w,XtPointer closure,XEvent *event,Boolean *cont)
 		OptionsCallback(options_popup,(XtPointer)NULL,(XtPointer)NULL);
 		return;
 	}
-	quit();
+	if(w == search_popup){
+		SearchCallback(search_popup,(XtPointer)NULL,(XtPointer)NULL);
+		return;
+	}
+	quit(NULL, NULL, NULL);
 	/* NOTREACHED */
 }
 
@@ -161,7 +171,7 @@ FILE *getusefile(){
 	}
 
 	if((f = fopen(fullname,"r")) == NULL){
-		printf("%s does not exist. Using entire dictionary...",
+		printf("%s does not exist. Using entire dictionary...\n",
 		         fullname);
 		usefile = NULL;
 	} else {
@@ -188,46 +198,46 @@ FILE *getusefile(){
 void initusefile(){
 	FILE *f;
 	char inbuf[100];
+	int count=0;
 
 	f = getusefile();
 
 
+	if(usefile == NULL){
 #ifndef HAS_MEMSET
-	if(usefile == NULL){
+		int kcount;
 		usefilecallback(usefilebutton,NULL,NULL);
-		i = MINKANJIALLOWED;
-		while(i<MAXKANJIALLOWED){
-			useKanji[i++] = 1;
+		kcount = MINKANJIALLOWED;
+		while(kcount<MAXTRANSLATIONSALLOWED){
+			useKanji[kcount++] = 1;
 		}
-		return;
-	} else {	/* set all to UNREADABLE, for now */
-#ifdef HAS_BZERO
-		bzero(useKanji,sizeof(Boolean[MAXKANJIALLOWED]));
-#else
-		i = MINKANJIALLOWED;
-		while(i<MAXKANJIALLOWED){
-			useKanji[i++] = 0;
-		}
-#endif /* HAS_BCOPY */
 #else /*HAS_MEMSET*/
-
-	if(usefile == NULL){
 		usefilecallback(usefilebutton,NULL,NULL);
-		memset(useKanji,1,sizeof(Boolean[MAXKANJIALLOWED]));
-		return;
-	} else {	/* set all to UNREADABLE, for now */
-		memset(useKanji,0,sizeof(Boolean[MAXKANJIALLOWED]));
-	}
+		memset(useKanji,1,sizeof(Boolean[MAXTRANSLATIONSALLOWED]));
 #endif /* HAS_MEMSET */
 
+		return;
+	} 
+	/*else set all to UNREADABLE, for now */
+	bzero(useKanji,sizeof(Boolean[MAXTRANSLATIONSALLOWED]));
+
 	while(fgets(inbuf,99,f) != NULL){
 		int usechar;
 		usechar = xtoi(inbuf);
-		if( usechar<MAXKANJIALLOWED)
+		if( usechar<MAXTRANSLATIONSALLOWED)
+		{
 			useKanji[usechar] = 1;
+			count++;
+		}
+	}
+	printf("read %d entries in usefile\n", count);
+	if(count < HAVE_AT_LEAST)
+	{
+		printf("Warning: forced to use less than minimum %d kanji.\n",
+		       HAVE_AT_LEAST);
 	}
-}
 
+}
 
 /* GetOptions
  *	get resource and command line options
@@ -236,6 +246,7 @@ void GetOptions(){
 	char tempnumber[10];
 
 	/* set grade bits appropriately */
+	GetXtString("gradelevel","Gradelevel",tempnumber);
 	parsegrades(tempnumber);
 
 	switchKanaEnglish = !GetXtBoolean("notallT","NotallT");
@@ -243,16 +254,15 @@ void GetOptions(){
 	doBell = !GetXtBoolean("noBell","NoBell");
 	showinorder = GetXtBoolean("showinorder","Showinorder");
 	if(GetXtBoolean("guessmeaning","Guessmeaning"))
-		Kanji2English = GUESSMEANING;
+		choicesmode = GUESS_ENGLISH;
 
 	lowfrequency = GetXtNumber("lowfrequency","Lowfrequency");
-	if((lowfrequency <0) || (lowfrequency >=MAXKANJIALLOWED))
+	if((lowfrequency <0) || (lowfrequency >=MAXTRANSLATIONSALLOWED))
 		lowfrequency = 0;
 	highfrequency = GetXtNumber("highfrequency","Highfrequency");
-	if((highfrequency <0) || (highfrequency >=MAXKANJIALLOWED))
+	if((highfrequency <0) || (highfrequency >=MAXTRANSLATIONSALLOWED))
 		highfrequency = 0;
 
-	GetXtString("gradelevel","Gradelevel",tempnumber);
 }
 
 
@@ -296,6 +306,9 @@ void initstuffs(int *argc,char *argv[])
 {
 	srand48 (time(NULL));
 
+	bzero(translations, sizeof(struct translationstruct *) * MAXTRANSLATIONSALLOWED);
+	lowestkanji = highestkanji = 0;
+
 	toplevel = XtVaAppInitialize(&Context,"KDrill",
  				   optionDescList,XtNumber(optionDescList),
  				   argc,argv,fallback,
@@ -326,7 +339,8 @@ void initstuffs(int *argc,char *argv[])
 	setup_deletewindow();
 
 	iconpixmap = XCreateBitmapFromData(display,mainwindow,
-			   icon_xbm_bits,icon_xbm_width,icon_xbm_height);
+			   (char *)icon_xbm_bits,
+			   icon_xbm_width,icon_xbm_height);
 
 	XtVaSetValues(toplevel,XtNiconName,"kdrill",
 			XtNiconPixmap,iconpixmap,NULL);
