@@ -1,6 +1,6 @@
 /* init.h */
 
 extern void initusefile(),initlog(),oldlog();
-extern Boolean useKanji[MAXKANJIALLOWED];
+extern Boolean useKanji[MAXTRANSLATIONSALLOWED];
 extern void initstuffs(int *,char **);
 
