@@ -54,8 +54,10 @@ void clean_up_structs(){
 		/* for some reason, 0 is better than NULL */
 		if(T->pronunciation != 0) 
 			free (T->pronunciation);
+#ifdef USE_OKU
 		if(T->ON_extra != 0)
 			free(T->pronunciation);
+#endif
 	}
 }
 
@@ -84,8 +86,10 @@ void usage(){
 	puts("Options:");
 	puts("  -usefile usefilename         Changes abridgement file of dictionary");
 	puts("  -nousefile                   Do not abridge initially");
-	puts("  -dictfile dictfilename       Changes dictionary file from");
+	puts("  -kdictfile dictfilename       Changes kanji dictionary file from");
 	puts("                               \"kanjidic\" to some other file");
+	puts("  -edictfile dictfilename       Changes phrase dictionary file from");
+	puts("                               \"edict\" to some other file");
 	puts("  -englishfont fontname        Changes english button font");
 	puts("  -kanjifont Kanjifontname     Changes LARGE kanji font");
 	puts("  -smallkanji Kanjifontname    Changes small kanji font");
@@ -94,6 +98,7 @@ void usage(){
 	puts("  -notallT                     Allow non-complete dictionary entries.");
 	puts("                                  warning: consult man-page.");
 	puts("  -showkana                    Start showing kana meanings instead of english");
+	puts("  -romajiswitch                Show kana meanings in romaji instead of kana");
 	puts("  -showinorder                 Go through kanji in order of #, NOT randomly");
 	puts("  -gradelevel                  Define while grades should be used.");
 	puts("                                use any or all of \"123456+\"");
@@ -108,15 +113,6 @@ void usage(){
 	exit(0);
 }
 
-/* Generic Beep routine that we can call from anywhere.
- * This way we don't have to check for enabled bell every time in the code.
- * We can just put Beep() whereever we feel like it.
- */
-void Beep(){
-	if(doBell)
-		XBell(display,100);
-}
-
 
 /* GetXtNumber(), GetXtBoolean(), GetXtString():
  *	Not the "best way" to get resources...
@@ -136,7 +132,7 @@ void Beep(){
  *	This should actually be encountered. I provide default values for
  *	all resource strings used.
  */
-void GetXtString(char *name,char *class,char *destinationstring)
+void GetXtString(char *name,char *rec_class, char *destinationstring)
 {
 	char resourcename[100],resourceclass[100];
 	char buffer[100];
@@ -152,7 +148,7 @@ void GetXtString(char *name,char *class,char *destinationstring)
 	resourceList.resource_class = resourceclass;
 
 	strcpy(resourcename,name);
-	strcpy(resourceclass,class);
+	strcpy(resourceclass,rec_class);
 
 	XtGetApplicationResources(toplevel,&returnstring,
 				  &resourceList,1,
@@ -165,11 +161,11 @@ void GetXtString(char *name,char *class,char *destinationstring)
  *	resource value in database.
  *	Will return default of 0!!!
  */
-int GetXtNumber(char *name,char *class)
+int GetXtNumber(char *name,char *rec_class)
 {
 	char resourcevalue[100];
 
-	GetXtString(name,class,resourcevalue);
+	GetXtString(name,rec_class,resourcevalue);
 	return atoi(resourcevalue);
 }
 /* GetXtBoolean()
@@ -177,7 +173,7 @@ int GetXtNumber(char *name,char *class)
  *
  *	default of False
  */
-Boolean GetXtBoolean(char *name,char *class)
+Boolean GetXtBoolean(char *name,char *rec_class)
 {
 	Boolean resourcevalue;
 	char resourcename[100],resourceclass[100];
@@ -191,7 +187,7 @@ Boolean GetXtBoolean(char *name,char *class)
 	resourceList.resource_class = resourceclass;
 
 	strcpy(resourcename,name);
-	strcpy(resourceclass,class);
+	strcpy(resourceclass,rec_class);
 
 	XtGetApplicationResources(toplevel,&resourcevalue,
 				  &resourceList,1,
@@ -199,6 +195,28 @@ Boolean GetXtBoolean(char *name,char *class)
 	return resourcevalue;
 }
 
+/* debugging routine.
+ * Prints out ALL english phrases loaded into memory.
+ * Note: This can be many thousands of lines!!!
+ */
+void dumpenglish()
+{
+	struct translationstruct *parse;
+
+	parse = translations[lowestkanji];
+
+	while(parse != NULL)
+	{
+		if(parse->english == NULL)
+		{
+			printf("NULL english\n");
+		} else
+		{
+			printf("English: %s\n", parse->english);
+		}
+		parse = parse->nextk;
+	}
+}
 
 
 /*
@@ -206,7 +224,6 @@ Boolean GetXtBoolean(char *name,char *class)
  */
 int main(int argc,char *argv[])
 {
-
 	puts("kdrill: Starting up... please wait a while.");
 	fflush(stdout);
 
@@ -219,16 +236,24 @@ int main(int argc,char *argv[])
 
 	/* check for abridgements of the dictionary... */
 	initusefile();
-	/* and actually read in structs of dictionary */
-	readstructs(&argc,argv);
+	/* and actually read in structs of kanjidic dictionary */
+	readstructs();
+	/* now try for 'edict' dictionary as well */
+	readedict();
 
+	/*dumpenglish();*/
+	
 	initlog(); /* old way or new way: same name */
 
-	showEnglish = ! GetXtBoolean("showkana","Showkana");
+	if( GetXtBoolean("showkana","Showkana"))
+		choicesmode = GUESS_KANA;
+	if( GetXtBoolean("romajiswitch","Romajiswitch"))
+		romajiswitch = 1;
 	CountKanji();
 	if(numberofkanji<HAVE_AT_LEAST){
 		fprintf(stderr,"There are two few kanji readable in the current configuration\n");
-		fprintf(stderr,"Please either reconfigure your usefile, or raise the grade level\n");
+		fprintf(stderr,"Please either reconfigure your usefile, raise the grade level,\n");
+		fprintf(stderr,"  or check your dictionary file,\n");
 		exit(0);
 	}
 
