@@ -2,5 +2,6 @@ extern void usefilecallback(Widget,XtPointer,XtPointer);
 extern void ordercallback(Widget,XtPointer,XtPointer);
 extern void OptionsCallback(Widget,XtPointer,XtPointer);
 extern Widget optionsform;
-extern Widget englishmode,togglekana;	/* needed for position info */
 extern void MakeOptionsPopup();
+
+extern Widget frequencyForm,gradelevelForm;
