@@ -1,5 +1,5 @@
-extern void readstructs();
-extern int xtoi(unsigned char *);
 extern int nextwork(unsigned char **);
 extern unsigned char *nextchar(unsigned char *c);
 extern void readstructs();
+extern void readedict();
+
